@@ -7,7 +7,7 @@ A blazing fast web framework for Rust
 Just add the following to your `Cargo.toml`:
 ```toml
 [dependencies]
-afire = "0.1.2"
+afire = "0.1.3"
 ```
 
 ## 📄 Info
@@ -133,6 +133,10 @@ pub use self::request::Request;
 mod response;
 pub use self::response::Response;
 
+// Query string stuff
+mod query;
+pub use self::query::Query;
+
 // Extra Features
 mod extensions;
 
